@@ -7,7 +7,17 @@ sys.path.insert(0, mydir+"/../../")
 # import n0struct
 # n0struct._DIFFTYPES = True  # For updating global variables using prefix is mandatory
 # n0struct._DIFFVALUES = True
-from n0struct import * # For using n0dict(), n0print(), n0debug without prefixes
+from n0struct import (
+    n0dict,
+    n0list,
+    n0print,
+    n0debug,
+    n0debug_calc,
+    set__flag_compare_check_different_types,
+    set__flag_compare_return_difference_of_values,
+    init_logger,
+    notemptyitems,
+)
 set__flag_compare_check_different_types(True)
 set__flag_compare_return_difference_of_values(True)
 init_logger(debug_timeformat = None, debug_show_object_id = False, debug_logtofile = False)
@@ -139,8 +149,10 @@ def main():
     dict1["moreone/node[new()]/value"] = None
     n0debug_calc(dict1,'dict1')  # Defect: new() has not converted single n0dict node into node[]
 
-    dict1["moreone/node[new()]/value"] = ""
-    dict1["moreone/node[new()]/value"] = 1
+    dict1["moreone/node[new()]/value"] = ""  # current and next lines generate 2 different new items
+    n0debug_calc(dict1,'dict1')
+    dict1["moreone/node[new()]/value"] = 1   # current and previous lines generate 2 different new items
+    n0debug_calc(dict1,'dict1')
     dict1["moreone/node[last()]/value"] = 2
     dict1["moreone/node[last()]/code"] = "two"
     dict1["moreone/node[new()]/value"] = 3
